__title__ = 'vision-ui'
__description__ = 'A line-oriented image diff algorithm.'
__url__ = 'https://github.com/Meituan-Dianping/vision-ui'
__version__ = '2.1.2'
__author__ = 'tech@meituan.com'
__author_email__ = ' tech@meituan.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2019 Meituan-Dianping'
__cake__ = u'\u2728 \U0001f370 \u2728'